@@ -31,3 +31,6 @@ class GammaUnivariate(ScipyModel):
 
     def _is_constant(self):
         return self._params['scale'] == 0
+
+    def _extract_constant(self):
+        return self._params['loc']
