@@ -1,9 +1,12 @@
-import matplotlib
 import pandas as pd
-from mpl_toolkits import mplot3d  # noqa: importing this fixes import error in py35
 
-matplotlib.use('PS')   # Avoid crash on macos
-import matplotlib.pyplot as plt   # noqa isort:skip
+try:
+    import matplotlib.pyplot as plt
+except RuntimeError as e:
+    if 'Python is not installed as a framework.' in e.message:
+        import matplotlib
+        matplotlib.use('PS')   # Avoid crash on macos
+        import matplotlib.pyplot as plt
 
 
 def scatter_3d(data, columns=None, fig=None, title=None, position=None):
