@@ -48,3 +48,16 @@ class TestTruncatedGaussian(TestCase):
         distribution.fit(np.array([1, 2, 3, 4]))
 
         assert not distribution._is_constant()
+
+    def test__extract_constant(self):
+        distribution = TruncatedGaussian()
+        distribution._params = {
+            'a': 1,
+            'b': 1,
+            'loc': 1,
+            'scale': 0
+        }
+
+        constant = distribution._extract_constant()
+
+        assert 1 == constant
